@@ -1,14 +1,28 @@
 #!/bin/sh
-# This gets/makes an original tarball based on the version in debian/changelog.
+# This gets/makes an original tarball.
+# By default, it uses the version in debian/changelog.
 # (By default using a tagged release)
-# This means that if you are upgrading upstream versions, you must first put the new release in debian/changelog!
+# This means that if you are upgrading upstream versions, please override VER in the environment!
 set -e
 
 COMMIT_HASH=
 # Only set explicitly in case we need a snapshot between releases
 # COMMIT_HASH=3d405f6a0427c411d30cc7ef4129e2e887f35e28
 REPACK_SUFFIX=$(dpkg-parsechangelog -S Version | sed -E 's/.*([+~]dfsg[0-9]+)-.*/\1/')
-VER=$(dpkg-parsechangelog -S Version | sed -e 's,.*:,,' -e 's,+dfsg.*,,')
+
+if [ "x${VER}" = x ]; then
+    VER=$(dpkg-parsechangelog -S Version | sed -e 's,.*:,,' -e 's,+dfsg.*,,')
+    echo "# Parsed upstream version to acquire from debian/changelog: $VER"
+else
+    echo "# Version to acquire overridden by environment: VER=$VER"
+fi
+
+for cmd in jq curl wget; do
+    if ! command -v $cmd > /dev/null; then
+        echo "# Need to install $cmd!"
+        exit 1
+    fi
+done
 
 if [ "x${COMMIT_HASH}" = "x" ]; then
     echo "# Looking up SHA for MeshLab version ${VER}"
@@ -49,3 +63,8 @@ mk-origtargz --repack --compression xz -S ${REPACK_SUFFIX} -C .. "meshlab_${VER}
 
 echo "# Cleaning up files"
 rm -f "meshlab_vcglib_${VER}.orig.tar.gz" "meshlab_${VER}.orig.tar"
+
+
+echo "# Run the following to update debian/copyright:"
+echo "sed -i 's:meshlab/archive/.*:meshlab/archive/${COMMIT_HASH}.tar.gz:' debian/copyright"
+echo "sed -i 's:vcglib/archive/.*:vcglib/archive/${VCGLIB_HASH}.tar.gz:' debian/copyright"
